# Libket

Libket serves as the core of the Ket Quantum Programming platform, providing a runtime library for the quantum programming language Ket, as well as simple interfaces for developing quantum applications in C/C++ and Rust. For more information,
please refer to the documentation at <https://quantumket.org>.

## Ket Quantum Programming platform  

![Ket Quantum Programming platform architecture](https://gitlab.com/quantum-ket/ket-everywhere/-/raw/main/architecture.png)

## Examples

For examples of Libket being used in Rust, C, and C++, check out the [Ket Everywhere repository](https://gitlab.com/quantum-ket/ket-everywhere).

## License

Libket is released under the Apache-2.0 License. See [LICENSE](LICENSE) for more information.
